#[non_exhaustive]pub struct TransferCounters {
pub objects_found: i64,
pub bytes_found: i64,
pub objects_skipped: i64,
pub bytes_skipped: i64,
pub objects_copied: i64,
pub bytes_copied: i64,
pub objects_failed: i64,
pub bytes_failed: i64,
/* private fields */
}Expand description
A collection of counters that report the progress of a transfer operation.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.objects_found: i64Objects found in the data source that are scheduled to be transferred, excluding any that are filtered based on object conditions or skipped due to sync.
bytes_found: i64Bytes found in the data source that are scheduled to be transferred, excluding any that are filtered based on object conditions or skipped due to sync.
objects_skipped: i64Objects in the data source that are not transferred because they already exist in the data destination.
bytes_skipped: i64Bytes in the data source that are not transferred because they already exist in the data destination.
objects_copied: i64Objects that are copied to the data destination.
bytes_copied: i64Bytes that are copied to the data destination.
objects_failed: i64Objects that failed to be written to the data destination.
bytes_failed: i64Bytes that failed to be written to the data destination.
Implementations
Sourceimpl TransferCounters
impl TransferCounters
Sourcepub fn set_objects_found<T: Into<i64>>(self, v: T) -> Self
pub fn set_objects_found<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_bytes_found<T: Into<i64>>(self, v: T) -> Self
pub fn set_bytes_found<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_objects_skipped<T: Into<i64>>(self, v: T) -> Self
pub fn set_objects_skipped<T: Into<i64>>(self, v: T) -> Self
Sets the value of objects_skipped.
Example
let x = TransferCounters::new().set_objects_skipped(42);Sourcepub fn set_bytes_skipped<T: Into<i64>>(self, v: T) -> Self
pub fn set_bytes_skipped<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_objects_copied<T: Into<i64>>(self, v: T) -> Self
pub fn set_objects_copied<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_bytes_copied<T: Into<i64>>(self, v: T) -> Self
pub fn set_bytes_copied<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_objects_failed<T: Into<i64>>(self, v: T) -> Self
pub fn set_objects_failed<T: Into<i64>>(self, v: T) -> Self
Sourcepub fn set_bytes_failed<T: Into<i64>>(self, v: T) -> Self
pub fn set_bytes_failed<T: Into<i64>>(self, v: T) -> Self