#[non_exhaustive]pub struct TransferOperationMetadata {
pub counters: Option<TransferCounters>,
pub transfer_type: TransferType,
pub error_summary: Vec<TransferErrorSummary>,
pub source: Option<Source>,
pub destination: Option<Destination>,
/* private fields */
}Expand description
Long-running operation metadata related to a data transfer.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.counters: Option<TransferCounters>Output only. The progress of the transfer operation.
transfer_type: TransferTypeOutput only. The type of transfer occurring.
error_summary: Vec<TransferErrorSummary>Output only. List of files that failed to be transferred. This list will have a maximum size of 5 elements.
source: Option<Source>The source of transfer operation.
destination: Option<Destination>The destination of transfer operation.
Implementations
Sourceimpl TransferOperationMetadata
impl TransferOperationMetadata
Sourcepub fn set_counters<T>(self, v: T) -> Selfwhere
T: Into<TransferCounters>,
pub fn set_counters<T>(self, v: T) -> Selfwhere
T: Into<TransferCounters>,
Sourcepub fn set_or_clear_counters<T>(self, v: Option<T>) -> Selfwhere
T: Into<TransferCounters>,
pub fn set_or_clear_counters<T>(self, v: Option<T>) -> Selfwhere
T: Into<TransferCounters>,
Sets or clears the value of counters.
Example
use google_cloud_parallelstore_v1::model::TransferCounters;
let x = TransferOperationMetadata::new().set_or_clear_counters(Some(TransferCounters::default()/* use setters */));
let x = TransferOperationMetadata::new().set_or_clear_counters(None::<TransferCounters>);Sourcepub fn set_transfer_type<T: Into<TransferType>>(self, v: T) -> Self
pub fn set_transfer_type<T: Into<TransferType>>(self, v: T) -> Self
Sets the value of transfer_type.
Example
use google_cloud_parallelstore_v1::model::TransferType;
let x0 = TransferOperationMetadata::new().set_transfer_type(TransferType::Import);
let x1 = TransferOperationMetadata::new().set_transfer_type(TransferType::Export);Sourcepub fn set_error_summary<T, V>(self, v: T) -> Self
pub fn set_error_summary<T, V>(self, v: T) -> Self
Sets the value of error_summary.
Example
use google_cloud_parallelstore_v1::model::TransferErrorSummary;
let x = TransferOperationMetadata::new()
.set_error_summary([
TransferErrorSummary::default()/* use setters */,
TransferErrorSummary::default()/* use (different) setters */,
]);Sourcepub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
pub fn set_source<T: Into<Option<Source>>>(self, v: T) -> Self
Sets the value of source.
Note that all the setters affecting source are mutually
exclusive.
Example
use google_cloud_parallelstore_v1::model::SourceParallelstore;
let x = TransferOperationMetadata::new().set_source(Some(
google_cloud_parallelstore_v1::model::transfer_operation_metadata::Source::SourceParallelstore(SourceParallelstore::default().into())));Sourcepub fn source_parallelstore(&self) -> Option<&Box<SourceParallelstore>>
pub fn source_parallelstore(&self) -> Option<&Box<SourceParallelstore>>
The value of source
if it holds a SourceParallelstore, None if the field is not set or
holds a different branch.
Sourcepub fn set_source_parallelstore<T: Into<Box<SourceParallelstore>>>(
self,
v: T,
) -> Self
pub fn set_source_parallelstore<T: Into<Box<SourceParallelstore>>>( self, v: T, ) -> Self
Sets the value of source
to hold a SourceParallelstore.
Note that all the setters affecting source are
mutually exclusive.
Example
use google_cloud_parallelstore_v1::model::SourceParallelstore;
let x = TransferOperationMetadata::new().set_source_parallelstore(SourceParallelstore::default()/* use setters */);
assert!(x.source_parallelstore().is_some());
assert!(x.source_gcs_bucket().is_none());Sourcepub fn source_gcs_bucket(&self) -> Option<&Box<SourceGcsBucket>>
pub fn source_gcs_bucket(&self) -> Option<&Box<SourceGcsBucket>>
The value of source
if it holds a SourceGcsBucket, None if the field is not set or
holds a different branch.
Sourcepub fn set_source_gcs_bucket<T: Into<Box<SourceGcsBucket>>>(self, v: T) -> Self
pub fn set_source_gcs_bucket<T: Into<Box<SourceGcsBucket>>>(self, v: T) -> Self
Sets the value of source
to hold a SourceGcsBucket.
Note that all the setters affecting source are
mutually exclusive.
Example
use google_cloud_parallelstore_v1::model::SourceGcsBucket;
let x = TransferOperationMetadata::new().set_source_gcs_bucket(SourceGcsBucket::default()/* use setters */);
assert!(x.source_gcs_bucket().is_some());
assert!(x.source_parallelstore().is_none());Sourcepub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
pub fn set_destination<T: Into<Option<Destination>>>(self, v: T) -> Self
Sets the value of destination.
Note that all the setters affecting destination are mutually
exclusive.
Example
use google_cloud_parallelstore_v1::model::DestinationGcsBucket;
let x = TransferOperationMetadata::new().set_destination(Some(
google_cloud_parallelstore_v1::model::transfer_operation_metadata::Destination::DestinationGcsBucket(DestinationGcsBucket::default().into())));Sourcepub fn destination_gcs_bucket(&self) -> Option<&Box<DestinationGcsBucket>>
pub fn destination_gcs_bucket(&self) -> Option<&Box<DestinationGcsBucket>>
The value of destination
if it holds a DestinationGcsBucket, None if the field is not set or
holds a different branch.
Sourcepub fn set_destination_gcs_bucket<T: Into<Box<DestinationGcsBucket>>>(
self,
v: T,
) -> Self
pub fn set_destination_gcs_bucket<T: Into<Box<DestinationGcsBucket>>>( self, v: T, ) -> Self
Sets the value of destination
to hold a DestinationGcsBucket.
Note that all the setters affecting destination are
mutually exclusive.
Example
use google_cloud_parallelstore_v1::model::DestinationGcsBucket;
let x = TransferOperationMetadata::new().set_destination_gcs_bucket(DestinationGcsBucket::default()/* use setters */);
assert!(x.destination_gcs_bucket().is_some());
assert!(x.destination_parallelstore().is_none());Sourcepub fn destination_parallelstore(
&self,
) -> Option<&Box<DestinationParallelstore>>
pub fn destination_parallelstore( &self, ) -> Option<&Box<DestinationParallelstore>>
The value of destination
if it holds a DestinationParallelstore, None if the field is not set or
holds a different branch.
Sourcepub fn set_destination_parallelstore<T: Into<Box<DestinationParallelstore>>>(
self,
v: T,
) -> Self
pub fn set_destination_parallelstore<T: Into<Box<DestinationParallelstore>>>( self, v: T, ) -> Self
Sets the value of destination
to hold a DestinationParallelstore.
Note that all the setters affecting destination are
mutually exclusive.
Example
use google_cloud_parallelstore_v1::model::DestinationParallelstore;
let x = TransferOperationMetadata::new().set_destination_parallelstore(DestinationParallelstore::default()/* use setters */);
assert!(x.destination_parallelstore().is_some());
assert!(x.destination_gcs_bucket().is_none());Trait Implementations
Sourceimpl Clone for TransferOperationMetadata
impl Clone for TransferOperationMetadata
Sourcefn clone(&self) -> TransferOperationMetadata
fn clone(&self) -> TransferOperationMetadata
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read moreSourceimpl Debug for TransferOperationMetadata
impl Debug for TransferOperationMetadata
Sourceimpl Default for TransferOperationMetadata
impl Default for TransferOperationMetadata
Sourcefn default() -> TransferOperationMetadata
fn default() -> TransferOperationMetadata
Sourceimpl Message for TransferOperationMetadata
impl Message for TransferOperationMetadata
impl StructuralPartialEq for TransferOperationMetadata